#
# spec file for package frei0r-plugins
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           frei0r-plugins
Version:        1.4
Release:        12.1
Summary:        Collection of video sources and filters plugins
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://frei0r.dyne.org/
Source:         http://files.dyne.org/frei0r/releases/frei0r-plugins-%{version}.tar.gz
# PATCH-FIX-UPSTREAM frei0r-plugins-1.4-missing_include.patch http://www.piksel.no/projects/frei0r/ticket/41 reddwarf@opensuse.org -- Add missing header
Patch0:         frei0r-plugins-1.4-missing_include.patch
# PATCH-FIX-UPSTREAM frei0r-plugins-openCV-3.0-compatibility.patch  tittiatcoke@gmail.com -- Make it compile with openCV3. This is a rebase of the two usptream commits by Dan Dennedy
Patch1:         frei0r-plugins-openCV-3.0-compatibility.patch
BuildRequires:  gcc-c++
# For the automatic pkgconfig() Provides
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(cairo) >= 1.0.0
BuildRequires:  pkgconfig(gavl) >= 0.2.3
%if 0%{?suse_version} > 1320 || (0%{?suse_version} == 1315 && 0%{?is_opensuse})
BuildRequires:  opencv-qt5-devel
%else
BuildRequires:  opencv-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a collection of video sources and filters plugins,
using the Frei0r API.

%package opencv
Summary:        OpenCV video sources and filters plugins
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{name} = %{version}-%{release}

%description opencv
These plugins may cause slow exports due to multiprocessing issues
in kdenlive and shotcut. plugins facebl0r and facedetect.
See boo#1068792

%package devel
Summary:        Frei0r plugin API for video sources and filters
# No Requires on main subpackage as there is no dependency between the two
Group:          Development/Libraries/C and C++

%description devel
Frei0r is a minimalistic plugin API for video sources and filters. The
behaviour of the effects can be controlled from the host by simple
parameters. The intent is to solve the recurring reimplementation or
adaptation issue of standard effects.

%prep
%setup -q
%patch0
%patch1 -p1
# Timestamp problem. Remove in next release.
touch include/config.h.in

%build
find -name Makefile.in -delete
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
# we'll package the relevant files with %%doc
rm %{buildroot}%{_datadir}/doc/frei0r-plugins/{AUTHORS,ChangeLog,README,TODO}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_libdir}/frei0r-1/
%exclude %{_libdir}/frei0r-1/facebl0r.so
%exclude %{_libdir}/frei0r-1/facedetect.so

%files opencv
%dir %{_libdir}/frei0r-1
%{_libdir}/frei0r-1/facebl0r.so
%{_libdir}/frei0r-1/facedetect.so

%files devel
%defattr(-,root,root)
%{_libdir}/pkgconfig/frei0r.pc
%{_includedir}/frei0r.h

%changelog
* Fri Dec 15 2017 davejplater@gmail.com
- Split off plugins built against OpenCV because they cause
  multiprocessing issues in shotcut and kdenlive. See boo#1068792
  and https://github.com/mltframework/mlt/issues/274.
* Fri Mar  4 2016 olaf@aepfle.de
- Fix frei0r-plugins-openCV-3.0-compatibility.patch
* Fri Mar  4 2016 zaitor@opensuse.org
- Update Url to http://frei0r.dyne.org/, show that we are using the
  fork and not the original frei0r.
* Thu Mar  3 2016 tittiatcoke@gmail.com
- Add frei0r-plugins-openCV-3.0-compatibility.patch: fix the
  compilation against OpenCV 3. This patch is based on the two
  upstream commits 129eea and 7ed3f84e6.
* Thu Nov 12 2015 ecsos@opensuse.org
- change if clause for opencv-qt5-devel, so no need for
  ProjectConfig
* Thu Nov  5 2015 wbauer@tmo.at
- Build against opencv-qt5-devel on Leap as well, Leap comes with
  the KF5/Qt5 based kdenlive (boo#930616)
* Sat May 16 2015 wbauer@tmo.at
- Build against opencv-qt5-devel on > 13.2, otherwise it would
  crash kdenlive/libmlt which are built against Qt5
* Wed Mar  6 2013 reddwarf@opensuse.org
- Update to version 1.4:
  * Fix several major bugs in existing plugins
  * Add new filters and the optional dependency to cairo.
  - New filters (18): IIRblur, Vignette, Keyspillm0pup, Timeout,
    Posterize, Dither, Spillsupress, Emboss, Colgate, RGBNoise,
    Colorize, Softglow, ColrHalftone, Sigmoidaltransfer,
    Colortap, cairogradient, cairoimagegrid, medians
  - New mixers: cairoblend, cairoaffineblend
- Remove frei0r-missing-return.patch and frei0r-plugins-compiler-warnings.patch
- Add frei0r-plugins-1.4-missing_include.patch
- Add pkgconfig(cairo) BuildRequires
* Wed Oct  5 2011 dimstar@opensuse.org
- Add pkgconfig(gavl) BuildRequires to enable the remaining
  filters: rgbparade, scale0tilt, vectorscope.
- Add frei0r-plugins-compiler-warnings.patch: Fix compiler warning
  on undefined operation. Patch taken from upstream git, commit
  id 8f8090.
* Wed Sep 28 2011 vuntz@opensuse.org
- Cleanup package.
* Sat Sep  3 2011 dimstar@opensuse.org
- Initial package, version 1.3.
